/*
 * Licensed to STRATIO (C) under one or more contributor license agreements.
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership.  The STRATIO (C) licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.stratio.crossdata.common.logicalplan;

import java.util.Set;

import com.stratio.crossdata.common.metadata.Operations;

/**
 * Limit the number of results in a query.
 */
public class Limit extends TransformationStep {

    private static final long serialVersionUID = -8755883109886275085L;
    /**
     * The number of tuples to be returned.
     */
    private final int limit;

    /**
     * Class constructor.
     *
     * @param limit  The max of results.
     * @param operations The operations to be applied.
     */
    public Limit(Set<Operations> operations, int limit) {
        super(operations);
        this.limit = limit;
    }

    public int getLimit() {
        return limit;
    }

    @Override
    public String toString() {
        return "LIMIT " + limit + " rows";
    }
}
