/*
 * Licensed to STRATIO (C) under one or more contributor license agreements.
 * See the NOTICE file distributed with this work for additional information
 * regarding copyright ownership.  The STRATIO (C) licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.stratio.crossdata.core.query;

import com.stratio.crossdata.common.result.QueryStatus;

/**
 * Class that implements the storage statements in the phase of validation.
 */
public class StorageValidatedQuery extends StorageParsedQuery implements IValidatedQuery {

    private String sqlQuery;

    /**
     * Constructor class based in a Storage Statement that was parsed.
     * @param storageParsedQuery the parsed statement.
     */
    public StorageValidatedQuery(StorageParsedQuery storageParsedQuery) {
        super(storageParsedQuery);
        setQueryStatus(QueryStatus.VALIDATED);
    }

    /**
     * Constructor class based in a validated Storage statement.
     * @param storageValidatedQuery The validated Statement.
     */
    public StorageValidatedQuery(StorageValidatedQuery storageValidatedQuery) {
        this((StorageParsedQuery) storageValidatedQuery);
    }

    /**
     * Get the sql direct query.
     * @return a String.
     */
    public String getSqlQuery() {
        return sqlQuery;
    }

    /**
     * Set the sql query obtained once normalizator phase is done.
     * @param sqlQuery The sql obtained in the normalizator phase.
     */
    public void setSqlQuery(String sqlQuery) {
        this.sqlQuery = sqlQuery;
    }

}
